package cz.jzitnik.chronos.entities;

import com.fasterxml.jackson.annotation.JsonIgnore;
import jakarta.persistence.*;
import com.fasterxml.jackson.annotation.JsonManagedReference;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

import java.util.ArrayList;
import java.util.List;

@Getter
@Setter
@Entity
@NoArgsConstructor
public class Game {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    @Column(unique = true, nullable = false)
    private String gameKey;

    @OneToMany(mappedBy = "game", cascade = CascadeType.ALL)
    @JsonManagedReference(value = "game-players")
    private List<Player> players = new ArrayList<>();

    @OneToMany(mappedBy = "game", cascade = CascadeType.ALL)
    @JsonIgnore
    private List<Room> rooms = new ArrayList<>();

    @OneToOne(cascade = CascadeType.ALL)
    @JoinColumn(name = "default_room_id", referencedColumnName = "id")
    private Room defaultRoom;

    @OneToOne(cascade = CascadeType.ALL)
    @JoinColumn(name = "admin_player_id", referencedColumnName = "id")
    @JsonIgnore
    private Player adminPlayer;

    @JsonIgnore
    private int keyFragmentsAmount = 0;

    @JsonIgnore
    private boolean won = false;

    @JsonIgnore
    private String wonMessage;

    private boolean started = false;

    public void addPlayer(Player player) {
        this.players.add(player);
    }

    @JsonIgnore
    public boolean winnable() {
        var ownedFragments = 0;
        for (Player player : players) {
            for (Item item : player.getInventory()) {
                if (item.getItemType() == ItemType.KEY_FRAGMENT) {
                    ownedFragments++;
                }
            }
        }


        var roomItems = 0;
        var characters = new ArrayList<Character>();

        for (Room room : rooms) {
            characters.addAll(room.getCharacters());
            for (Item item : room.getItems()) {
                if (item.getItemType() == ItemType.KEY_FRAGMENT) {
                    roomItems++;
                }
            }
        }

        var unplayedCharacters = characters.stream().filter(character -> !character.isInteractedWith()).toList().size();

        return (roomItems + unplayedCharacters + ownedFragments) >= (5 - keyFragmentsAmount);
    }
}
