package cz.jzitnik.game;

import cz.jzitnik.api.ApiService;
import cz.jzitnik.api.types.Item;
import cz.jzitnik.api.types.Player;
import cz.jzitnik.utils.Cli;
import lombok.AllArgsConstructor;
import org.apache.hc.core5.http.HttpStatus;

import java.io.IOException;
import java.util.Arrays;

@AllArgsConstructor
public class PlayerList {
    private ApiService apiService;
    private String playerKey;


    public void display() throws IOException {
        var response = apiService.getAllPlayers(playerKey).execute();
        var players = response.body().getData().get();

        Cli.printHeader("List všech hráčů");

        for (Player player1 : players) {
            System.out.println("Jméno: " + Cli.Colors.BLUE + player1.getName() + Cli.Colors.RESET + ", V místnosti: " + Cli.Colors.BLUE + player1.getCurrentRoom() + Cli.Colors.RESET);
        }

        if (players.size() == 1) {
            // There is only one player so can't send item to another player
            return;
        }

        System.out.println("\n");
        var options = new String[] { "Předat item hráči", "Zavřít list hráčů"};

        var selectedIndex = Cli.selectOptionIndex(Arrays.asList(options));

        if (selectedIndex == 1) {
            return;
        }

        // Select item from inventory
        var res = apiService.getMe(playerKey).execute();
        var me = res.body().getData().get();
        var inventory = me.getInventory();

        if (inventory.isEmpty()) {
            Cli.error("Nemáte žádné itemy v inventáři");
            return;
        }

        var playerList = players.stream().filter(player -> !player.getId().equals(me.getId())).toList();
        var playerOptions = playerList.stream().map(Player::getName).toList();

        System.out.println("\n\nVyberte hráče kterému chcete dát item");
        var selectedPlayerIndex = Cli.selectOptionIndex(playerOptions);
        var selectedPlayer = playerList.get(selectedPlayerIndex);

        System.out.println("\n\nVyberte item který chcete dát hráči");
        var items = inventory.stream().map(Item::toString).toList();
        var selectedItemIndex = Cli.selectOptionIndex(items);
        var selectedItem = inventory.get(selectedItemIndex);

        var finalResponse = apiService.sendItem(playerKey, selectedItem.getId(), selectedPlayer.getId()).execute();

        if (finalResponse.code() == HttpStatus.SC_CONFLICT) {
            Cli.error("Hráč " + Cli.Colors.BLUE + selectedPlayer.getName() + Cli.Colors.RESET + " má plný inventář!");
            return;
        }

        Cli.success("Item byl úspěšně předán hráči " + Cli.Colors.BLUE + selectedPlayer.getName() + Cli.Colors.RESET + ".");
    }
}
